﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            xamDataChart1.Series.Clear();

            MyBubbleDataCollection1 b1 = new MyBubbleDataCollection1();
            MyBubbleDataCollection2 b2 = new MyBubbleDataCollection2();
            AddBubbleSeries(b1, MarkerType.Circle, Colors.Brown);
            AddBubbleSeries(b2, MarkerType.Square, Colors.Coral);
        }

        private void AddBubbleSeries(ObservableCollection<BubbleDataPoint> dataCollection, MarkerType markerType, Color markerColor)
        {
            BubbleSeries bs;
            bs = new BubbleSeries();

            bs.BorderThickness = new Thickness(1);
            bs.XAxis = xmXAxis;
            bs.YAxis = xmYAxis;
            bs.XMemberPath = "X";
            bs.YMemberPath = "Y";
            bs.RadiusMemberPath = "Radius";

            bs.LabelMemberPath = "Label";
            bs.FillMemberPath = "MarkerBrush";

            bs.MarkerType = markerType;
            bs.MarkerBrush = new SolidColorBrush(markerColor);

            bs.ItemsSource = dataCollection;
            xamDataChart1.Series.Add(bs);
        }
    }


    public class MyBubbleDataCollection1 : ObservableCollection<BubbleDataPoint>
    {
        public MyBubbleDataCollection1()
        {
            this.Add(new BubbleDataPoint { X = 1, Y = 1, Radius = 10, Label = "label", MarkerBrush = 0x0000FF }); //blue
            this.Add(new BubbleDataPoint { X = 2, Y = 2, Radius = 12, Label = "label", MarkerBrush = 0x0000FF });
            this.Add(new BubbleDataPoint { X = 3, Y = 3, Radius = 15, Label = "label", MarkerBrush = 0x0000FF });
        }
    }

    public class MyBubbleDataCollection2 : ObservableCollection<BubbleDataPoint>
    {
        public MyBubbleDataCollection2()
        {
            this.Add(new BubbleDataPoint { X = 1, Y = 2, Radius = 10, Label = "label", MarkerBrush = 0x00FF00 }); //green
            this.Add(new BubbleDataPoint { X = 2, Y = 3, Radius = 12, Label = "label", MarkerBrush = 0x00FF00 });
            this.Add(new BubbleDataPoint { X = 3, Y = 4, Radius = 15, Label = "label", MarkerBrush = 0x00FF00 });
        }
    }
    
    public class BubbleDataPoint : ObservableModel
    {

        #region Properties

        private double _y;
        public double Y
        {
            get { return _y; }
            set { if (_y == value) return; _y = value; OnPropertyChanged("Y"); }
        }

        private double _x;
        public double X
        {
            get { return _x; }
            set { if (_x == value) return; _x = value; OnPropertyChanged("X"); }
        }

        private double _radius;
        public double Radius
        {
            get { return _radius; }
            set { if (_radius == value) return; _radius = value; OnPropertyChanged("Radius"); }
        }
        private double _markerBrush;
        public double MarkerBrush
        {
            get { return _markerBrush; }
            set { if (_markerBrush == value) return; _markerBrush = value; OnPropertyChanged("MarkerBrush"); }
        }

        private string _label;
        public string Label
        {
            get { return _label; }
            set { if (_label == value) return; _label = value; OnPropertyChanged("Label"); }
        }

        #endregion

        //public new string ToString()
        //{
        //    return String.Format("X {0}, Y {1}, Radius {2}", X, Y, Radius);
        //}
    }

    public abstract class ObservableModel : INotifyPropertyChanged
    {
        protected ObservableModel()
        {

        }

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
                handler(this, new PropertyChangedEventArgs(propertyName));
        }

        public void OnAsyncPropertyChanged(string propertyName)
        {
            //if (PropertyChanged != null)
            //{
            //    System.Deployment.Current.Dispatcher.BeginInvoke(() =>
            //    {
            //        PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            //    });
            //}
        }
        #endregion
    }

}
